==> qtjambi-network-debuginfo-windows-x64-5.15.20.jar: sources/QtJambiNetwork/QIPv6Address_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtNetwork/qhostaddress.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QIPv6Address(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QIPv6Address")
    QIPv6Address *_ptr = reinterpret_cast<QIPv6Address *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QIPv6Address()
void __qt_construct_QIPv6Address(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIPv6Address()")
    Q_UNUSED(__java_arguments)
    QIPv6Address *__qt_this = new(__qtjambi_ptr) QIPv6Address();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QIPv6Address::QIPv6Address()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_initialize_1native__Lio_qt_network_QIPv6Address_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIPv6Address::QIPv6Address()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIPv6Address, sizeof(QIPv6Address), typeid(QIPv6Address), false, &deleter_QIPv6Address, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QIPv6Address(QIPv6Address)
void __qt_construct_QIPv6Address_cref_QIPv6Address(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIPv6Address(QIPv6Address)")
    jobject other0 = __java_arguments[0].l;
    const QIPv6Address& __qt_other0 = qtjambi_cast<const QIPv6Address& >(__jni_env, other0);
    QIPv6Address *__qt_this = new(__qtjambi_ptr) QIPv6Address(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QIPv6Address::QIPv6Address(QIPv6Address)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_initialize_1native__Lio_qt_network_QIPv6Address_2Lio_qt_network_QIPv6Address_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIPv6Address::QIPv6Address(QIPv6Address)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIPv6Address_cref_QIPv6Address, sizeof(QIPv6Address), typeid(QIPv6Address), false, &deleter_QIPv6Address, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QIPv6Address{quint8[16]}
void __qt_construct_QIPv6Address_quint8(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIPv6Address{quint8[16]}")
    QtJambiScope __qtjambi_scope;
    jbyteArray c0 = static_cast<jbyteArray>(__java_arguments[0].l);
    jsize c0_array_size{0};
    if((c0_array_size = __jni_env->GetArrayLength(jarray(c0))) != 16)
        JavaException::raiseIllegalArgumentException(__jni_env, QString("Argument 'c': Wrong number of elements in array. Found: %1, expected: 16").arg(c0_array_size) QTJAMBI_STACKTRACEINFO);
    quint8 * c0_array = qtjambi_array_cast<quint8*>(__jni_env, __qtjambi_scope, c0, 16);
    QIPv6Address *__qt_this = new(__qtjambi_ptr) QIPv6Address{{c0_array[0], c0_array[1], c0_array[2], c0_array[3], c0_array[4], c0_array[5], c0_array[6], c0_array[7], c0_array[8], c0_array[9], c0_array[10], c0_array[11], c0_array[12], c0_array[13], c0_array[14], c0_array[15]}};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QIPv6Address::QIPv6Address{quint8[16]}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_initialize_1native__Lio_qt_network_QIPv6Address_2_3B)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jbyteArray c0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIPv6Address::QIPv6Address{quint8[16]}")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = c0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIPv6Address_quint8, sizeof(QIPv6Address), typeid(QIPv6Address), false, &deleter_QIPv6Address, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QIPv6Address
void __qt_destruct_QIPv6Address(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QIPv6Address")
    reinterpret_cast<QIPv6Address*>(ptr)->~QIPv6Address();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QIPv6Address::operator[](int)const
extern "C" Q_DECL_EXPORT jbyte JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_get_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    Q_UNUSED(__this)
    jbyte __java_return_value{0};
    QTJAMBI_TRY {
        const QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QIPv6Address::operator[](int)const", __qt_this)
        quint8 __qt_return_value = (*__qt_this)[static_cast<int>(index0)];
        __java_return_value = jbyte(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QIPv6Address::operator[](int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_set_1native_1int_1quint8__JIB)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0,
 jbyte value1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QIPv6Address::operator[](int)", __qt_this)
        (*__qt_this)[static_cast<int>(index0)] = static_cast<quint8>(value1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_setC_1native_1quint8__J_3B)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jbyteArray c0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        jsize c0_array_size{0};
        if((c0_array_size = __jni_env->GetArrayLength(jarray(c0))) != 16)
            JavaException::raiseIllegalArgumentException(__jni_env, QString("Argument 'c': Wrong number of elements in array. Found: %1, expected: 16").arg(c0_array_size) QTJAMBI_STACKTRACEINFO);
        quint8 * c0_array = qtjambi_array_cast<quint8*>(__jni_env, __qtjambi_scope, c0, 16);
        __qt_this->c[0] = c0_array[0];
        __qt_this->c[1] = c0_array[1];
        __qt_this->c[2] = c0_array[2];
        __qt_this->c[3] = c0_array[3];
        __qt_this->c[4] = c0_array[4];
        __qt_this->c[5] = c0_array[5];
        __qt_this->c[6] = c0_array[6];
        __qt_this->c[7] = c0_array[7];
        __qt_this->c[8] = c0_array[8];
        __qt_this->c[9] = c0_array[9];
        __qt_this->c[10] = c0_array[10];
        __qt_this->c[11] = c0_array[11];
        __qt_this->c[12] = c0_array[12];
        __qt_this->c[13] = c0_array[13];
        __qt_this->c[14] = c0_array[14];
        __qt_this->c[15] = c0_array[15];
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jbyteArray JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_c_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jbyteArray __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        quint8 * __qt_value = __qt_this->c;
        __java_return_value = QtJambiAPI::toJByteArray(__jni_env, reinterpret_cast<jbyte*>(__qt_value), 16);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QIPv6Address(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QIPv6Address>("QIPv6Address", "io/qt/network/QIPv6Address");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QIPv6Address, {
        ConstructorInfo(&__qt_construct_QIPv6Address, nullptr)
       ,ConstructorInfo(&__qt_construct_QIPv6Address_cref_QIPv6Address, "Lio/qt/network/QIPv6Address;")
       ,ConstructorInfo(&__qt_construct_QIPv6Address_quint8, "[B")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QIPv6Address);
    registerMetaType<QIPv6Address>("QIPv6Address");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-network-debuginfo-windows-x64-6.5.5.jar: sources/QtJambiNetwork/QIPv6Address_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtNetwork/qhostaddress.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QIPv6Address(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QIPv6Address")
    QIPv6Address *_ptr = reinterpret_cast<QIPv6Address *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QIPv6Address()
void __qt_construct_QIPv6Address(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIPv6Address()")
    Q_UNUSED(__java_arguments)
    QIPv6Address *__qt_this = new(__qtjambi_ptr) QIPv6Address();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QIPv6Address::QIPv6Address()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_initialize_1native__Lio_qt_network_QIPv6Address_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIPv6Address::QIPv6Address()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIPv6Address, sizeof(QIPv6Address), typeid(QIPv6Address), false, &deleter_QIPv6Address, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QIPv6Address(QIPv6Address)
void __qt_construct_QIPv6Address_cref_QIPv6Address(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIPv6Address(QIPv6Address)")
    jobject other0 = __java_arguments[0].l;
    const QIPv6Address& __qt_other0 = qtjambi_cast<const QIPv6Address& >(__jni_env, other0);
    QIPv6Address *__qt_this = new(__qtjambi_ptr) QIPv6Address(__qt_other0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QIPv6Address::QIPv6Address(QIPv6Address)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_initialize_1native__Lio_qt_network_QIPv6Address_2Lio_qt_network_QIPv6Address_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIPv6Address::QIPv6Address(QIPv6Address)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIPv6Address_cref_QIPv6Address, sizeof(QIPv6Address), typeid(QIPv6Address), false, &deleter_QIPv6Address, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QIPv6Address{quint8[16]}
void __qt_construct_QIPv6Address_quint8_16_(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QIPv6Address{quint8[16]}")
    QtJambiScope __qtjambi_scope;
    jbyteArray c0 = static_cast<jbyteArray>(__java_arguments[0].l);
    Q_ASSERT(__jni_env->GetArrayLength(jarray(c0)) >= 16);
    quint8 * __qt_c0 = qtjambi_array_cast<quint8*>(__jni_env, __qtjambi_scope, c0, 16);
    QIPv6Address *__qt_this = new(__qtjambi_ptr) QIPv6Address{{__qt_c0[0], __qt_c0[1], __qt_c0[2], __qt_c0[3], __qt_c0[4], __qt_c0[5], __qt_c0[6], __qt_c0[7], __qt_c0[8], __qt_c0[9], __qt_c0[10], __qt_c0[11], __qt_c0[12], __qt_c0[13], __qt_c0[14], __qt_c0[15]}};
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QIPv6Address::QIPv6Address{quint8[16]}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_initialize_1native__Lio_qt_network_QIPv6Address_2_3B)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jbyteArray c0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QIPv6Address::QIPv6Address{quint8[16]}")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = c0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QIPv6Address_quint8_16_, sizeof(QIPv6Address), typeid(QIPv6Address), false, &deleter_QIPv6Address, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QIPv6Address
void __qt_destruct_QIPv6Address(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QIPv6Address")
    reinterpret_cast<QIPv6Address*>(ptr)->~QIPv6Address();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QIPv6Address::operator[](int)const
extern "C" Q_DECL_EXPORT jbyte JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_get_1native_1int_1constfct__JI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0)
{
    Q_UNUSED(__this)
    jbyte __java_return_value{0};
    QTJAMBI_TRY {
        const QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QIPv6Address::operator[](int)const", __qt_this)
        quint8 __qt_return_value = (*__qt_this)[static_cast<int>(index0)];
        __java_return_value = jbyte(__qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QIPv6Address::operator[](int)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_set_1native_1int_1quint8__JIB)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jint index0,
 jbyte value1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QIPv6Address::operator[](int)", __qt_this)
        (*__qt_this)[static_cast<int>(index0)] = static_cast<quint8>(value1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_setC_1native_1cref_1quint8_116_1__J_3B)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jbyteArray c0)
{
    QtJambiScope __qtjambi_scope(__this_nativeId);
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        Q_ASSERT(__jni_env->GetArrayLength(jarray(c0)) >= 16);
        quint8 * __qt_c0 = qtjambi_array_cast<quint8*>(__jni_env, __qtjambi_scope, c0, 16);
        __qt_this->c[0] = static_cast<quint8>(__qt_c0[0]);
        __qt_this->c[1] = static_cast<quint8>(__qt_c0[1]);
        __qt_this->c[2] = static_cast<quint8>(__qt_c0[2]);
        __qt_this->c[3] = static_cast<quint8>(__qt_c0[3]);
        __qt_this->c[4] = static_cast<quint8>(__qt_c0[4]);
        __qt_this->c[5] = static_cast<quint8>(__qt_c0[5]);
        __qt_this->c[6] = static_cast<quint8>(__qt_c0[6]);
        __qt_this->c[7] = static_cast<quint8>(__qt_c0[7]);
        __qt_this->c[8] = static_cast<quint8>(__qt_c0[8]);
        __qt_this->c[9] = static_cast<quint8>(__qt_c0[9]);
        __qt_this->c[10] = static_cast<quint8>(__qt_c0[10]);
        __qt_this->c[11] = static_cast<quint8>(__qt_c0[11]);
        __qt_this->c[12] = static_cast<quint8>(__qt_c0[12]);
        __qt_this->c[13] = static_cast<quint8>(__qt_c0[13]);
        __qt_this->c[14] = static_cast<quint8>(__qt_c0[14]);
        __qt_this->c[15] = static_cast<quint8>(__qt_c0[15]);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jbyteArray JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_c_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jbyteArray __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        quint8 * __qt_value = __qt_this->c;
        __java_return_value = QtJambiAPI::toJByteArray(__jni_env, reinterpret_cast<jbyte *>(__qt_value), 16);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_network_QIPv6Address_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QIPv6Address *__qt_this = QtJambiAPI::objectFromNativeId<QIPv6Address>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QIPv6Address(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QIPv6Address>("QIPv6Address", "io/qt/network/QIPv6Address");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QIPv6Address, {
        ConstructorInfo(&__qt_construct_QIPv6Address, nullptr)
       ,ConstructorInfo(&__qt_construct_QIPv6Address_cref_QIPv6Address, "Lio/qt/network/QIPv6Address;")
       ,ConstructorInfo(&__qt_construct_QIPv6Address_quint8_16_, "[B")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QIPv6Address);
    registerMetaType<QIPv6Address>("QIPv6Address");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
